# モーター

OpenMVにはIOポートがあり、様々なモーターを駆動することができます。

## ステッピングモーター

### ステッピングモーターとは

ステッピング モーターは、電気パルス信号を角度変位または線形変位に変換する開ループ制御モーターであり、最新のデジタル
プログラム制御システムの主要な実行要素であり、広く使用されています。

3Dプリンターやロボットアームなど。

### ステッピングモータードライバーボード

多くのチップやモジュールがステッピング モーターを制御できます。ここでは、EasyDriver という非常にシンプルなモジュールを使用します。

簡単に言うと、dirで方向を制御し、stepにパルスを与えるとモーターは1ステップ動きます。

![](/assets/06-07-001.jpg)

### 接続する

![](/assets/06-07-002.jpg)

## モジュールのインストール

[モジュール コードはこのリンクにあります](http://book.openmv.cc/module/write-module-motor.html)

このクラスのコードを stepper.py ファイルとして保存し、OpenMV のルート ディレクトリに置きます。

## コード

```python
# 步进电机控制 - By: 小智智- 周日 4月 2 2017

from pyb import Pin

from stepper import Stepper

import time

step_pin = Pin('P0')
dir_pin = Pin('P1')

my_stepper = Stepper(step_pin,dir_pin)

print("relative angle move test begin:", my_stepper.read_pos())
my_stepper.rel_angle(180)#相对角度控制
print("relative angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("steps angle move test end:", my_stepper.read_pos())
my_stepper.steps(-400)#步进脉冲控制
print("steps angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("absolute angle move test begin:", my_stepper.read_pos())
my_stepper.abs_angle(0)#绝对角度控制
print("absolute angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)
```

## DCモーター

#### チュートリアル 26 - DC モーターを制御するモーター拡張バージョン: [https://singtown.com/video](https://singtown.com/video)

### DCモーターとは

DC モーターの速度は電圧に正比例します。

### ドライバーボード

多くのドライバー ボードは DC モーターを駆動できますが、ここではデュアル H ブリッジの TB6612FNG を使用します。

![](/assets/06-07-003.jpg)

### 接続する

![](/assets/06-07-004.jpg)

### コード

```python
待添加
```

## ステアリングギア

OpenMV2 には P7 と P8 という 2 つのサーボ ピンがあります。

OpenMV3 には P7、P8、P9 の 3 つのサーボ ピンがあります。

### 接続する

![](/assets/06-07-005.jpg)

### 電源を確認してください

サーボは高電流デバイスであるため、外部電源 (安定化電源、リチウム電池など) を使用する必要があります。USB ではサーボに電力を供給できません。

### コード

```python
# Servo Control Example
#
# This example shows how to use your OpenMV Cam to control servos.

import time
from pyb import Servo

s1 = Servo(1) # P7
s2 = Servo(2) # P8
#s3 = Servo(3) # P9 Only for OpenMV3 M7
while(True):
    for i in range(-90,90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
    for i in range(90,-90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
```

## PCA9685は複数のサーボを接続します

赤ちゃんのリンク:
[https://singtown.com/product/49277](https://singtown.com/product/49277)

#### ビデオ チュートリアル 25 - pca9685 は複数のサーボを制御します: [https://singtown.com/learn/50057/](https://singtown.com/learn/50057/)



PCA9685 モジュールは、2 つのピン (I2C プロトコル) のみを使用して、16 個の PWM チャネル (16 個のサーボまたは 16 個の LED
ライト) を制御できます。 62 個のモジュールを接続しても、2 つのピンのみを使用して 992 個の PWM を制御することもできます。

接続する

![](/assets/06-07-006-01.jpg)

コード

![](/assets/06-07-007.jpg)

クリックして実行

